import * as path from 'path';

import babel from 'rollup-plugin-babel';
import cleanup from 'rollup-plugin-cleanup';
import commonjs from 'rollup-plugin-commonjs';
import copy from 'rollup-plugin-copy';
import { eslint } from 'rollup-plugin-eslint';
import regenerator from 'rollup-plugin-regenerator';
import resolve from 'rollup-plugin-node-resolve';
import { terser } from 'rollup-plugin-terser';

import assert, { PATTERN } from './tools/rollup-plugin-assert';
import findReplace from './tools/rollup-plugin-find-replace';
import iifeLemonPI from './tools/rollup-plugin-lemonpi-iife';

module.exports = {
  input: path.join(__dirname, 'src', 'script.js'),
  output: {
    file: path.join(__dirname, 'dist', 'script.js'),
    format: 'cjs',
    esModule: false,
  },
  treeshake: false,
  plugins: [
    assert(),
    eslint(),
    resolve(),
    babel({
      exclude: 'node_modules/**',
      externalHelpers: false,
      runtimeHelpers: true,
    }),
    regenerator({
      includeRuntime: false,
    }),
    commonjs(),
    cleanup(),
    terser(),
    iifeLemonPI({
      banner: '/* eslint-disable */\n',
    }),
    findReplace([[PATTERN, 'return ']]),
    copy({
      targets: [
        { src: ['src/manifest.json', 'src/panel.json'], dest: 'dist' },
      ],
    }),
  ],
};
