import request from 'request';

import config from './config';
import prettyLog from './prettyLog';

export default (email, password) => new Promise((resolve, reject) => {
  const options = {
    url: config.lemonpiLoginApiUrl,
    headers: { 'Content-Type': 'application/json' },
    body: JSON.stringify({ email, password }),
  };

  request.post(options, (err, _, body) => {
    if (err) {
      prettyLog('FAILED TO AUTHORIZE', 'ERROR', err.toString());
      return reject(err);
    }

    try {
      const { token } = JSON.parse(body);
      if (!token) {
        throw new Error('Missing token in response. Check your credentials.');
      }
      return resolve(token);
    } catch (e) {
      prettyLog('FAILED TO AUTHORIZE', 'ERROR', e.toString());
      return reject(e);
    }
  });
});
