import { readFileSync } from 'fs';
import chalk from 'chalk';
import request from 'request';

import config from './config';
import prettyLog from './prettyLog';

const { archiveFilePath, lemonpiPluginApiUrl, archiveFileName } = config;

export { archiveFilePath as location };

export default token => new Promise(async (resolve, reject) => {
  const options = {
    url: lemonpiPluginApiUrl,
    headers: { Authorization: `lemonpi ${token}` },
    formData: {
      plugin: {
        value: readFileSync(archiveFilePath),
        options: {
          filename: archiveFileName,
          contentType: 'application/octet-stream',
        },
      },
    },
  };

  request.post(options, (err, res, body) => {
    if (err) {
      prettyLog('FAILED TO DEPLOY', 'ERROR', err.toString());
      return reject(err);
    }

    try {
      if (typeof body === 'string' && body.length) {
        const data = JSON.parse(body);

        if (data.error) {
          throw new Error(data.error.kind);
        }
      }
    } catch (e) {
      if (res.statusCode !== 200) {
        prettyLog('FAILED TO DEPLOY', 'ERROR', e.toString());
        return reject(e);
      }
    }

    prettyLog('DEPLOY SUCCESSFUL', 'OK', `Your plugin ${chalk.black.bgGreen(` ${archiveFileName} `)}, has been deployed! It can take a little while before Studio also refreshes the plugin. This usually takes about 1-5 minutes. Try restarting the application completely (not just your current window) a few times just to make sure the updated plugin is available!`);

    return resolve();
  });
});
